| Title: | "Cereal Headers for R and C++ Serialization" |
|---|---|
| Description: | To facilitate using 'cereal' with R via 'cpp11' or 'Rcpp'. 'cereal' is a header-only C++11 serialization library. 'cereal' takes arbitrary data types and reversibly turns them into different representations, such as compact binary encodings, 'XML', or 'JSON'. 'cereal' was designed to be fast, light-weight, and easy to extend - it has no external dependencies and can be easily bundled with other code or used standalone. Please see <https://uscilab.github.io/cereal/> for more information. |
| Authors: | Wush Wu [aut, cre] (ORCID: <https://orcid.org/0000-0001-5180-0567>), Randolph Voorhies [ctb], Shane Grant [ctb], Stephen Wade [ctb] (ORCID: <https://orcid.org/0000-0002-2573-9683>) |
| Maintainer: | Wush Wu <[email protected]> |
| License: | BSD_2_clause + file LICENSE |
| Version: | 1.3.2 |
| Built: | 2026-06-07 08:53:40 UTC |
| Source: | https://github.com/wush978/rcereal |
Uses the GitHub API to find the latest version of cereal.
last_version()last_version()
Gets all the versions from GitHub via list_version() and selects the
largest version number.
package_version
Use the GitHub API to query the versions of cereal.
list_version()list_version()
The GitHub page of cereal is https://github.com/USCiLab/cereal, the
tags are accessed via the GitHub API, from which a package_version object
is coerced.
package_version, a vector of available versions.
Clone a different version of the cereal headers into R library.
update_version(version = last_version(), ...)update_version(version = last_version(), ...)
version |
|
... |
additional arguments passed to |
This over-writes the installed cereal headers inside an R library. The
default location for the files is found via system.file(). The library
location can be specified by passing an argument lib.loc. See
system.file() for further details.